==> micro-website-base-core-1.2.5-sources.jar: com/ptteng/sca/micro/common/client/GcomponentSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.Gcomponent;
import com.ptteng.micro.common.service.GcomponentService;

import java.util.List;
import java.util.Map;

public class GcomponentSCAClient implements GcomponentService {

    private GcomponentService gcomponentService;

	public GcomponentService getGcomponentService() {
		return gcomponentService;
	}
	
	
	public void setGcomponentService(GcomponentService gcomponentService) {
		this.gcomponentService =gcomponentService;
	}
	
	
			   
		@Override
		public Long insert(Gcomponent gcomponent)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.insert(gcomponent);
		          
		
		}	
		  
    	   
		@Override
		public List<Gcomponent> insertList(List<Gcomponent> gcomponentList)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.insertList(gcomponentList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Gcomponent gcomponent)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.update(gcomponent);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Gcomponent> gcomponentList)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.updateList(gcomponentList);
		          
		
		}	
		  
    	   
		@Override
		public Gcomponent getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Gcomponent> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(Long merchantId,Integer type,String key,Integer level,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(merchantId,type,key,level,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndKey(Long merchantId,String key,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndKey(merchantId,key,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndTypeAndKey(Long merchantId,Integer type,String key,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndTypeAndKey(merchantId,type,key,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantId(Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantId(merchantId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndLevel(Long merchantId,Integer level,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndLevel(merchantId,level,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndType(Long merchantId,Integer type,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndType(merchantId,type,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(Long merchantId,Integer type,String key,Integer level)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(merchantId,type,key,level);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndKey(Long merchantId,String key)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndKey(merchantId,key);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndTypeAndKey(Long merchantId,Integer type,String key)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndTypeAndKey(merchantId,type,key);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantId(Long merchantId)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantId(merchantId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndLevel(Long merchantId,Integer level)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndLevel(merchantId,level);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndType(Long merchantId,Integer type)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndType(merchantId,type);
	
	
	}
	
		
	
		@Override
	public List<Long> getGcomponentIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.getGcomponentIds(start, limit);
	}

	@Override
	public Integer countGcomponentIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.countGcomponentIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   gcomponentService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.gcomponentService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> micro-website-base-core-2.1.1-sources.jar: com/ptteng/sca/micro/common/client/GcomponentSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.Gcomponent;
import com.ptteng.micro.common.service.GcomponentService;

import java.util.List;
import java.util.Map;

public class GcomponentSCAClient implements GcomponentService {

    private GcomponentService gcomponentService;

	public GcomponentService getGcomponentService() {
		return gcomponentService;
	}
	
	
	public void setGcomponentService(GcomponentService gcomponentService) {
		this.gcomponentService =gcomponentService;
	}
	
	
			   
		@Override
		public Long insert(Gcomponent gcomponent,String lang)throws Exception{
		
		return gcomponentService.insert(gcomponent,lang);
		          
		
		}	
		  
    	   
		@Override
		public List<Gcomponent> insertList(List<Gcomponent> gcomponentList,String lang)throws Exception{
		
		return gcomponentService.insertList(gcomponentList,lang);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id,String lang)throws Exception{
		
		return gcomponentService.delete(id,lang);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Gcomponent gcomponent)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.update(gcomponent);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Gcomponent> gcomponentList)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.updateList(gcomponentList);
		          
		
		}	
		  
    	   
		@Override
		public Gcomponent getObjectById(Long id,String lang)throws Exception{
		
		return gcomponentService.getObjectById(id,lang);
		          
		
		}	
		  
    	   
		@Override
		public List<Gcomponent> getObjectsByIds(List<Long> ids,String lang)throws Exception{
		
		return gcomponentService.getObjectsByIds(ids,lang);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(Long merchantId,Integer type,String key,Integer level,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(merchantId,type,key,level,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndKey(Long merchantId,String key,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndKey(merchantId,key,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndTypeAndKey(Long merchantId,Integer type,String key,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndTypeAndKey(merchantId,type,key,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantId(Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantId(merchantId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndLevel(Long merchantId,Integer level,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndLevel(merchantId,level,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getGcomponentIdsByMerchantIdAndType(Long merchantId,Integer type,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.getGcomponentIdsByMerchantIdAndType(merchantId,type,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(Long merchantId,Integer type,String key,Integer level)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndTypeAndKeyAndLevel(merchantId,type,key,level);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndKey(Long merchantId,String key)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndKey(merchantId,key);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndTypeAndKey(Long merchantId,Integer type,String key)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndTypeAndKey(merchantId,type,key);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantId(Long merchantId)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantId(merchantId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndLevel(Long merchantId,Integer level)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndLevel(merchantId,level);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countGcomponentIdsByMerchantIdAndType(Long merchantId,Integer type)throws ServiceException, ServiceDaoException{
		
		return gcomponentService.countGcomponentIdsByMerchantIdAndType(merchantId,type);
	
	
	}
	
		
	
		@Override
	public List<Long> getGcomponentIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.getGcomponentIds(start, limit);
	}

	@Override
	public Integer countGcomponentIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.countGcomponentIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return gcomponentService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   gcomponentService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.gcomponentService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}
